@@ -467,7 +467,7 @@ class School:
                 access=response_json["access_token"],
                 refresh=response_json["refresh_token"])
             else:
-                raise Exception('todo')
+                raise Exception('Credentials are incorrect, or maybe SSO external provider (which is not yet implemented here..')
                 
             
         # if last_response_final_response.status_code == 200:
